pitchtools.inventory_inversion_equivalent_diatonic_interval_classes
===================================================================

.. autofunction:: abjad.tools.pitchtools.inventory_inversion_equivalent_diatonic_interval_classes.inventory_inversion_equivalent_diatonic_interval_classes
